.\" file MASS/isoMDS.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN isoMDS
.TL
Kruskal's Non-metric Multidimensional Scaling
.DN
One form of non-metric multidimensional scaling
.CS
isoMDS(d, y = cmdscale(d, k), k = 2, maxit = 50, trace = T)
.RA
.AG d
distance structure of the form returned by `dist', or a full, symmetric
matrix.  Data are assumed to be dissimilarities or relative distances,
but must be positive except for self-distance.
.OA
.AG y
An initial configuration. If none is supplied, `cmdscale' is used to provide
the classical solution. The dimension of the initial configuration
determines that of the answer
.AG k
The desired dimension for the solution.
.AG maxit
The maximum number of iterations.
.AG trace
Logical for tracing optimization. Default `true'.
.RT
Two components:
.RC points
A two-column vector of the fitted configuration.
.RC stress
The final stress achieved (in percent).
.SE
If `trace' is true, the initial stress and the current stress are printed
out every 5 iterations.
.DT
This chooses a k-dimensional (default k = 2) configuration to minimize
the stress, the square root of the ratio of the the sum of squared
differences between the input distances and those of the configuration
to the sum of configuration distances squared. However, the input
distances are allowed a monotonic transformation.
.PP
An iterative algorithm is used, which will usually converge in around
10 iterations. As this is necessarily an O(n^2) calculation, it is slow
for large datasets. Further, since the configuration is only determined
up to rotations and reflections (by convention the centroid is at the
origin), the result can vary considerably from machine to machine.
.SH REFERENCE
T. F. Cox and M. A. A. Cox (1994) 
.ul
Multidimensional Scaling.
Chapman & Hall.
.SA
`cmdscale', `sammon'
.EX
swiss.dist <- dist(swiss.x)
swiss.mds <- isoMDS(swiss.dist)
plot(swiss.mds$points, type="n")
text(swiss.mds$points, labels=as.character(1:nrow(swiss.x)))
swiss.sh <- Shepard(swiss.dist, swiss.mds$points)
plot(swiss.sh)
lines(swiss.sh$x, swiss.sh$yf, type="S")
.KW multivariate
.WR
